%global ppp_ver %(rpm -q --queryformat "%{VERSION}" ppp)

Summary:		An L2TP client/server, designed for VPN use
Name:			openl2tp
Version:		1.8
Release:		%mkrel 25
License:		GPLv2
Group:			System/Base
URL:			http://www.openl2tp.org
Source0:		https://sourceforge.net/projects/openl2tp/files/openl2tp/%{version}/openl2tp-%{version}.tar.gz
Source1:		openl2tp.service
Source2:		openl2tp-tmpfiles.conf
Patch0:			openl2tp-1.8-make.patch
Patch1:			no-Werror.pach
Patch2:			fix-build-with-glibc-2.32.patch 
# From PLD
Patch3:			openl2tp-tirpc.patch
#
Requires:		ppp = %{ppp_ver}
Requires:		readline >= 4.2
Requires:		rpcbind
Requires(post):		systemd >= %{systemd_required_version}
Requires(post):		rpm-helper
Requires(preun):	rpm-helper

BuildRequires:		ppp-devel >= 2.4.8
BuildRequires:		readline-devel >= 4.2
BuildRequires:		glibc >= 2.4
BuildRequires:		flex
BuildRequires:		bison
BuildRequires:		rpcgen
BuildRequires:		pkgconfig(libtirpc)
BuildRequires:		kernel-headers >= 2.6.23

%description
OpenL2TP is a complete implementation of RFC2661 - Layer Two Tunneling
Protocol Version 2, able to operate as both a server and a client. It
is ideal for use as an enterprise L2TP VPN server, supporting more
than 100 simultaneous connected users. It may also be used as a client
on a home PC or roadwarrior laptop.

OpenL2TP has been designed and implemented specifically for Linux. It
consists of

- a daemon, openl2tpd, handling the L2TP control protocol exchanges
  for all tunnels and sessions

- a plugin for pppd to allow its PPP connections to run over L2TP
  sessions

- a Linux kernel driver for efficient datapath (integrated into the
  standard kernel from 2.6.23).

- a command line application, l2tpconfig, for management.

%package devel
Summary: OpenL2TP support files for plugin development
Group: Development/Other

%description devel
This package contains support files for building plugins for OpenL2TP,
or applications that use the OpenL2TP APIs.

%prep
%setup -q
%autopatch -p0
# rpcgen generates only a subset of methods on armv7hl for some reason :(
%ifarch armv7hl
sed -i 's/L2TP_FEATURE_RPC_MANAGEMENT=.*/L2TP_FEATURE_RPC_MANAGEMENT=n/' Makefile
%endif

%build
%__make CFLAGS.optimize="%{optflags} $(pkg-config --cflags libtirpc) -Wno-unused-but-set-variable -Wno-error=format-truncation" SYS_LIBDIR=%{_libdir} PPPD_VERSION=%{ppp_ver} PPPD_SUBDIR=

%install
%make_install SYS_LIBDIR=%{_libdir} PPPD_VERSION=%{ppp_ver} PPPD_SUBDIR=
%{__mkdir} -p %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/openl2tp.service
%{__cp} -f etc/sysconfig/openl2tpd %{buildroot}%{_sysconfdir}/sysconfig/openl2tpd
%{__install} -D -p -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}

%files
%doc README LICENSE
%{_tmpfilesdir}/%{name}.conf
%dir %{_libdir}/openl2tp
%{_sbindir}/openl2tpd
%{_libdir}/openl2tp/ppp_null.so
%{_libdir}/openl2tp/ppp_unix.so
%{_libdir}/openl2tp/ipsec.so
%{_libdir}/openl2tp/event_sock.so
%{_mandir}/man4/openl2tp_rpc.4.*
%{_mandir}/man5/openl2tpd.conf.5.*
%{_mandir}/man7/openl2tp.7.*
%{_mandir}/man8/openl2tpd.8.*
%{_unitdir}/openl2tp.service
%config %{_sysconfdir}/sysconfig/openl2tpd
%ifnarch armv7hl
%{_bindir}/l2tpconfig
%{_mandir}/man1/l2tpconfig.1.*
%endif

%files devel
%doc plugins/README doc/README.event_sock
%{_libdir}/openl2tp/l2tp_rpc.x
%{_libdir}/openl2tp/l2tp_event.h
%{_libdir}/openl2tp/event_sock.h




%changelog
* Sat Dec 05 2020 ghibo <ghibo> 1.8-25.mga8
+ Revision: 1652746
- Add further patch from PLD to fix build against newer glibc 2.32/libtirpc
+ tv <tv>
- Fix building with libtirpc
- BR rpcgen (fix build with glibc-2.32)

* Fri Oct 16 2020 luigiwalser <luigiwalser> 1.8-23.mga8
+ Revision: 1636395
- rebuild for ppp 2.4.8

* Fri Mar 13 2020 tv <tv> 1.8-22.mga8
+ Revision: 1556055
- fix build by compiling w/o -Werror
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ luigiwalser <luigiwalser>
- rebuild for readline

* Sat Nov 03 2018 umeabot <umeabot> 1.8-20.mga7
+ Revision: 1327877
- Mageia 7 Mass Rebuild

* Sun Jun 24 2018 wally <wally> 1.8-19.mga7
+ Revision: 1239543
- fix build on aarch64
+ kekepower <kekepower>
- Use new make macros

* Tue Jan 02 2018 wally <wally> 1.8-18.mga7
+ Revision: 1189455
- rebuild for new readline

* Sat Jul 30 2016 pterjan <pterjan> 1.8-17.mga6
+ Revision: 1044030
- Fix file list on armv7hl

* Sat Jul 30 2016 pterjan <pterjan> 1.8-16.mga6
+ Revision: 1044025
- Try again...

* Sat Jul 30 2016 pterjan <pterjan> 1.8-15.mga6
+ Revision: 1044018
- Fix build on armv7hl

* Mon Feb 08 2016 umeabot <umeabot> 1.8-14.mga6
+ Revision: 942527
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.8-13.mga5
+ Revision: 750823
- Second Mageia 5 Mass Rebuild

* Wed Oct 08 2014 alexl <alexl> 1.8-12.mga5
+ Revision: 737536
- fixed license tag
- cleanup spec
- changed url tag
- rebuilt with ppp-2.4.7

* Tue Sep 16 2014 umeabot <umeabot> 1.8-11.mga5
+ Revision: 683220
- Mageia 5 Mass Rebuild

* Wed Mar 19 2014 alexl <alexl> 1.8-10.mga5
+ Revision: 605862
- add rpcbind.target

* Tue Mar 18 2014 alexl <alexl> 1.8-9.mga5
+ Revision: 604878
- fix type for openl2tp service: openl2tp is not simple, but forking

* Mon Mar 10 2014 alexl <alexl> 1.8-8.mga5
+ Revision: 601796
- move killproc, because no killproc in Mageia, and systemd can stop openl2tp service (mga#10103)
- add preload l2tp_ppp with according /etc/rc.d/init.d/openl2tpd (mga#10103)

* Sat Oct 19 2013 umeabot <umeabot> 1.8-7.mga4
+ Revision: 522658
- Mageia 4 Mass Rebuild

* Sun Mar 24 2013 colin <colin> 1.8-6.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sun Mar 03 2013 dlucio <dlucio> 1.8-5.mga3
+ Revision: 401305
- temp file fixed
- systemd service fixed

* Fri Mar 01 2013 dlucio <dlucio> 1.8-4.mga3
+ Revision: 400891
- Tipo

* Fri Mar 01 2013 dlucio <dlucio> 1.8-3.mga3
+ Revision: 400867
- Service policy align
- New S1 & S2

* Sun Jan 13 2013 umeabot <umeabot> 1.8-2.mga3
+ Revision: 362045
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 02 2013 dlucio <dlucio> 1.8-1.mga3
+ Revision: 337738
- imported package openl2tp


* Wed Jul 06 2011 Александр Казанцев <kazancas@mandriva.org> 1.8-1
+ Revision: 689030
- initial release for Mandriva
- imported package openl2tp
- Created package structure for openl2tp.

